@@ -28,11 +28,7 @@ sub parse_arg {
         # (otherwise it hurts when user types //deep/directory/name)
         $self->{parent} = 1;
 
-        my $path = get_prompt(loc("Enter a depot path to copy into (under // if no leading '/'): ")) || '//A';
-        $path =~ s{^//+}{};
-        $path =~ s{//+}{/};
-        $path = "//$path" unless $path =~ m!^/!;
-        $path =~ s{/$}{};
+        my $path = $self->prompt_depotpath("copy");
 
         if ($dst =~ /^\.?$/) {
             $self->{_checkout_path} = (splitdir($path))[-1];
