@@ -19,10 +19,15 @@ sub parse_arg {
     return if @arg > 2;
     unshift @arg, '' while @arg < 2;
 
+    local $@;
     if (eval { $self->{xd}->find_repos($arg[1]); 1 }) {
         # Reorder to put DEPOTPATH before PATH
         @arg[0,1] = @arg[1,0];
     }
+    elsif (!eval { $self->{xd}->find_repos($arg[0]); 1 }) {
+        # The user entered a path 
+        @arg = $arg[0], $self->prompt_depotpath('import');
+    }
 
     return ($self->arg_depotpath ($arg[0]), $self->arg_path ($arg[1]));
 }
