@@ -169,7 +169,8 @@ sub find_merge_sources {
     my $minfo = $verbatim ? $info->verbatim : $info->resolve ($target->{repos});
     return $minfo if $verbatim;
 
-    my %ancestors = $self->copy_ancestors ($target->{repos}, $target->path, $target->{revision}, 1);
+    my %ancestors = $self->copy_ancestors ($target->{repos}, $target->path,
+					   $target->{revision}, 1, 1);
     for (sort keys %ancestors) {
 	my $rev = $ancestors{$_};
 	$minfo->{$_} = $rev
@@ -180,7 +181,7 @@ sub find_merge_sources {
 }
 
 sub copy_ancestors {
-    my ($self, $repos, $path, $rev, $nokeep) = @_;
+    my ($self, $repos, $path, $rev, $nokeep, $reverse) = @_;
     my $fs = $repos->fs;
     my $root = $fs->revision_root ($rev);
     $rev = $root->node_created_rev ($path);
@@ -240,7 +241,10 @@ sub copy_ancestors {
 	}
     }
     return () unless $found;
-    return ("$myuuid:$hpath" => $hrev, $self->copy_ancestors ($repos, $hpath, $hrev));
+
+    my @ret = $self->copy_ancestors ($repos, $hpath, $hrev, 0, $reverse);
+
+    return $reverse ? (@ret, "$myuuid:$hpath" => $hrev) : ("$myuuid:$hpath" => $hrev, @ret);
 }
 
 sub get_new_ticket {
@@ -263,10 +267,10 @@ sub log {
     my $print_rev = SVK::Command::Log::_log_remote_rev
 	($self->{repos}, $self->{src}->path, $self->{remoterev},
 	 '@'.($self->{host} || (split ('\.', hostname, 2))[0]));
-    my $sep = $verbatim ? '' : ('-' x 70)."\n";
+    my $sep = $verbatim || $self->{verbatim} ? '' : ('-' x 70)."\n";
     my $cb_log = sub {
 	SVK::Command::Log::_show_log
-		(@_, $sep, $buf, 1, $print_rev)
+		(@_, $sep, $buf, 1, $print_rev, 0, $self->{verbatim} ? 1 : 0)
 		    unless $self->_is_merge_from ($self->{src}->path, $self->{dst}, $_[0]);
     };
 
@@ -449,6 +453,16 @@ sub del_target {
     return $self;
 }
 
+sub remove_duplicated {
+    my ($self, $other) = @_;
+    for (keys %$other) {
+	if ($self->{$_} && $self->{$_}{rev} <= $other->{$_}{rev}) {
+	    delete $self->{$_};
+	}
+    }
+    return $self;
+}
+
 sub subset_of {
     my ($self, $other) = @_;
     my $subset = 1;
